import request from '@/utils/request'

export function fetchKeywordList(params) {
  return request({
    url: '/keyword/keyword/list',
    method: 'get',
    params
  })
}

export function joinKeywordLibrary(params) {
  return request({
    url: '/keyword/join/label',
    method: 'get',
    params
  })
}

export function fetchKeywordRecommendList(params) {
  return request({
    url: '/keyword/recommend/list',
    method: 'get',
    params
  })
}

export function ignoreKeyword(params) {
  return request({
    url: '/keyword/ignore/label',
    method: 'get',
    params
  })
}

export function addKeyword(params) {
  return request({
    url: '/keyword/insert/label',
    method: 'get',
    params
  })
}

export function deleteKeyword(params) {
  return request({
    url: '/keyword/delete/label',
    method: 'get',
    params
  })
}

export function importKeywordXlsx(data) {
  return request({
    url: '/keyword/import/label',
    method: 'post',
    data,
    headers: {
      'Content-Type': 'multipart/form-data'
    }
  })
}

export function importKeywordLabelXlsx(data) {
  return request({
    url: '/keyword/import/keywordLabel',
    method: 'post',
    data,
    headers: {
      'Content-Type': 'multipart/form-data'
    }
  })
}

// 关键词下拉联动开启
export function findLinkageStatus(params) {
  return request({
    url: '/keyword/findLinkageStatus',
    method: 'get',
    params
  })
}
/**
 * 协销列表
 * @returns
 */
export function getServiceList(params) {
  return request({
    url: '/keyword/getServiceList',
    method: 'get',
    params
  })
}
/**
 * 静态标签列表
 * @param {*} keyword 标签
 * @param {*} beginTime 统计开始时间
 * @param {*} endTime 统计结束时间
 * @param {*} serviceProviderId 协销Id
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function getStatekeywordList(params) {
  return request({
    url: '/keyword/statekeyword/list',
    method: 'get',
    params
  })
}
/**
 * 优先展示标签列表
 * @param {*} keyword 标签
 * @param {*} fromSearch 来源
 * @param {*} dynamicStatus 0 为动态标签 1 静态标签
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function getPriorKeywordList(params) {
  return request({
    url: '/keyword/getPriorKeywordList',
    method: 'get',
    params
  })
}
/**
 * 选择标签弹窗列表
 * @param {*} keyword 标签
 * @param {*} fromSearch 来源
 * @param {*} dynamicStatus 0 为动态标签 1 静态标签
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function getPickKeyword(params) {
  return request({
    url: '/keyword/getPickKeyword',
    method: 'get',
    params
  })
}
/**
 * 保存优先展示标签
 * @param {*} searchIds 标签
 * @returns
 */
export function savePriorKeyword(params) {
  return request({
    url: '/keyword/savePriorKeyword',
    method: 'get',
    params
  })
}
/**
 * 删除优先展示标签
 * @param {*} id 标签Id
 * @returns
 */
export function delPriorKeyword(params) {
  return request({
    url: '/keyword/delPriorKeyword',
    method: 'get',
    params: params
  })
}
/**
 * 删除动静态标签
 * @param {*} id 标签Id
 * @returns
 */
export function deleteTrendsLabel(params) {
  return request({
    url: '/keyword/delete/TrendsLabel',
    method: 'get',
    params
  })
}
/**
 * 选择子标签弹窗列表(未关联父标签的子标签列表)
 * @param {*} keyword 标签
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function getSubtagKeyword(params) {
  return request({
    url: '/keyword/getSubtagKeyword',
    method: 'get',
    params
  })
}
/**
 * 保存静态&动态标签
 * @param {*} keyword 标签名称
 * @param {*} dynamicStatus	0：动态标签；1：静态标签
 * @param {*} subtagId	子标签集合
 * @returns
 */
export function saveLabelByState(data) {
  return request({
    url: '/keyword/saveLabelByState',
    method: 'post',
    data: data
  })
}

/**
 * 获取标签详情
 * @param {*} id 标签id
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function editKeyword(params) {
  return request({
    url: '/keyword/editKeyword',
    method: 'get',
    params
  })
}
