import request from '@/utils/request'

/**
 * 用户咨询记录汇总
 * @param {*} remarks 标签词
 * @param {*} consult 咨询类别
 * @param {*} clubName 机构名称
 * @param {*} newDeal 新分配机构状态 0 全部 1 是  2否
 * @param {*} isRegister 是否注册 0 全部 1 未注册 2已注册
 * @param {*} todayTime 时间
 * @param {*} serviceProviderId 协销Id
 * @param {*} pageNum,
 * @param {*} pageSize
 * @returns
 */
export function getRemarksRegistList(params) {
  return request({
    url: '/user/remarks/registList',
    method: 'get',
    params
  })
}
/**
 * 获取咨询类别
 * @returns
 */
export function getClassName(params) {
  return request({
    url: '/user/remarks/getClassName',
    method: 'get',
    params
  })
}
/**
 * 获取当天协销咨询记录信息
 * @param {*} accessDate 时间
 * @returns
 */
export function getServiceList(params) {
  return request({
    url: '/user/remarks/getServiceList',
    method: 'get',
    params
  })
}
/**
 * 咨询记录类别列表
 * @param {*} className 类别名称
 * @param {*} status 状态
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function getConsultList(params) {
  return request({
    url: '/user/remarks/getConsultList',
    method: 'get',
    params
  })
}
/**
 * 添加保存咨询记录类别
 * @param {*} className 类别名称
 * @param {*} sortNumber 类别排序
 * @returns
 */
export function saveConsult(data) {
  return request({
    url: '/user/remarks/saveConsult',
    method: 'post',
    data: data
  })
}
/**
 * 删除类别
 * @param {*} id 类别Id
 * @returns
 */
export function deleteConsult(id) {
  return request({
    url: '/user/remarks/deleteConsult/' + id,
    method: 'get'
  })
}

/**
 * 设置类别排序
 * @param {*} id 类别Id
 * @param {*} sortNumber 类别排序
 * @returns
 */
export function consultSort(params) {
  return request({
    url: '/user/remarks/sort',
    method: 'get',
    params
  })
}
/**
 * 获取报备列表
 * @param {*} reportId 报备Id
 * @param {*} productName 咨询商品名称
 * @param {*} clubName 机构名称
 * @param {*} reportName 报备人
 * @param {*} status 状态 1.已审核 2.待审核 3.审核未通过
 * @param {*} startAddTime 提交开始时间
 * @param {*} endAddTime 提交结束时间
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function getReportList(params) {
  return request({
    url: '/user/remarks/ReportList',
    method: 'get',
    params
  })
}
/**
 * 审核报备
 * @param {*} auditText 审核备注
 * @param {*} status 报备状态
 */
export function reportCount(params) {
  return request({
    url: '/user/remarks/reportCount',
    method: 'get',
    params
  })
}

/**
 * 删除报备
 * @param {*} reportId 报备Id
 * @returns
 */
export function deleteReport(id) {
  return request({
    url: '/user/remarks/deleteReport/' + id,
    method: 'get'
  })
}

/**
 * 报备详情
 * @param {*} reportId 报备
 * @returns
 */
export function cmRegistReportList(params) {
  return request({
    url: '/user/remarks/cmRegistReportList',
    method: 'get',
    params
  })
}

/**
 * 取消报备关联
 * @param {*}  remarksId 供应商Id
 * @param {*} type 关键词
 * @returns
 */
export function getAudit(params) {
  return request({
    url: '/user/remarks/audit',
    method: 'get',
    params
  })
}
/**
 * 未注册咨询记录
 * @param {*} questionMan 咨询人
 * @param {*} serviceProviderId 协销Id
 * @param {*} concat 是否同步
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function visitRemarkList(params) {
  return request({
    url: '/user/remarks/visitRemarkList',
    method: 'get',
    params
  })
}
/**
 * 未注册用户已同步数据详情
 * @param {*} clubId 机构Id
 * @param {*} questionManId 咨询人Id
 * @param {*} remarks 标签词
 * @param {*} consult 类别
 * @param {*} startAddTime 开始时间
 * @param {*} endAddTime 结束时间
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 */
export function remarksList(params) {
  return request({
    url: '/user/remarks/remarksList',
    method: 'get',
    params
  })
}
/**
 * 文件下载
 * @param {*} fileName 文件名称
 * @param {*} ossName 阿里云oss名称
 */
export function remarksFileDownload(data) {
  return request({
    url: '/user/remarks/remarks/download',
    method: 'post',
    data: data
  })
}
