import request from '@/utils/request'

/**
 * 潜客搜集供应商列表
 * @param {*} shopName
 * @param {*} status
 * @param {*} pageNum,
 * @param {*} pageSize
 * @returns
 */
export function getCustomerShopList(params) {
  return request({
    url: '/user/customer/getCustomerShopList',
    method: 'get',
    params
  })
}
/**
 * 选择已上线供应商列表
 * @param {*} shopName
 * @param {*} pageNum,
 * @param {*} pageSize
 * @returns
 */
export function getShopList(params) {
  return request({
    url: '/user/customer/getShopList',
    method: 'get',
    params
  })
}
/**
 * 保存添加统计供应商
 * @param {*} shopIds
 * @returns
 */
export function saveCustomerShop(params) {
  return request({
    url: '/user/customer/saveCustomerShop',
    method: 'get',
    params
  })
}
/**
 * 设置供应商统计状态
 * @param {*} id 统计供应商表的ID
 * @param {*} status 统计状态
 * @returns
 */
export function renewCustomerShop(params) {
  return request({
    url: '/user/customer/renewCustomerShop',
    method: 'get',
    params
  })
}
/**
 * 供应商相关游客统计列表
 * @param {*} shopId 供应商Id
 * @param {*} consultName 咨询人姓名
 * @param {*} consultMobile 咨询手机号
 * @param {*} pageNum 咨询手机号
 * @param {*} pageSize 咨询手机号
 * @returns
 */
export function getCmInformationList(params) {
  return request({
    url: '/user/customer/getCmInformationList',
    method: 'get',
    params
  })
}
/**
 * 设置潜客跟进状态
 * @param {*} id 潜客列表ID
 * @param {*} followUpStatus 跟进状态
 * @returns
 */
export function renewFollowUpStatus(params) {
  return request({
    url: '/user/customer/renewFollowUpStatus',
    method: 'get',
    params
  })
}
/**
 * 供应商相关文章列表
 * @param {*} shopId 供应商Id
 * @param {*} infoId 列表文章Id
 * @param {*} title 标题
 * @param {*} status  统计状态
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function getShopInfoList(params) {
  return request({
    url: '/user/customer/getShopInfoList',
    method: 'get',
    params
  })
}
/**
 * 供应商选择文章列表
 * @param {*} id 文章Id
 * @param {*} title 标题
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function getInfoList(params) {
  return request({
    url: '/user/customer/getInfoList',
    method: 'get',
    params
  })
}
/**
 * 添加文章
 * @param {*} shopId 供应商Id
 * @param {*} infoIds 文章Id合集
 */
export function saveShopInfo(params) {
  return request({
    url: '/user/customer/saveShopInfo',
    method: 'get',
    params
  })
}
/**
 * 设置文章统计状态
 * @param {*} id 文章统计Id
 * @param {*} status 统计状态
 * @returns
 */
export function renewShopInfo(params) {
  return request({
    url: '/user/customer/renewShopInfo',
    method: 'get',
    params
  })
}
/**
 * 删除文章
 * @param {*} id 文章统计Id
 * @returns
 */
export function delShopInfo(id) {
  return request({
    url: '/user/customer/delShopInfo/' + id,
    method: 'get'
  })
}
/**
 * 供应商相关搜索词列表
 * @param {*} shopId 供应商Id
 * @param {*} keyword 关键词
 * @param {*} status  统计状态
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function getShopKeywordList(params) {
  return request({
    url: '/user/customer/getShopKeywordList',
    method: 'get',
    params
  })
}
/**
 * 供应商选择文搜索词列表
 * @param {*} keyword 标题
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function getSearchFrequencyList(params) {
  return request({
    url: '/user/customer/getSearchFrequencyList',
    method: 'get',
    params
  })
}
/**
 * 添加关键词
 * @param {*} shopId 供应商Id
 * @param {*} keyWordIds 文章Id合集
 */
export function saveShopKeyword(params) {
  return request({
    url: '/user/customer/saveShopKeyword',
    method: 'get',
    params
  })
}
/**
 * 设置关键词统计状态
 * @param {*} id 关键词统计Id
 * @param {*} status 统计状态
 * @returns
 */
export function renewShopKeyword(params) {
  return request({
    url: '/user/customer/renewShopKeyword',
    method: 'get',
    params
  })
}
/**
 * 删除关键词
 * @param {*} id 关键词统计Id
 * @returns
 */
export function delShopKeyword(id) {
  return request({
    url: '/user/customer/delShopKeyword/' + id,
    method: 'get'
  })
}
/**
 * 供应商广告弹窗信息保存
 * @param {*} id 关键词统计Id
 * @param {*} shopId 供应商Id
 * @param {*} image 弹窗图片
 * @param {*} guidingOne 引导语1
 * @param {*} guidingTwo 引导语2
 * @param {*} addTime 添加时间
 * @returns
 */
export function saveShopPopUp(data) {
  return request({
    url: '/user/customer/saveShopPopUp',
    method: 'post',
    data: data
  })
}
/**
 * 供应商广告弹窗样式回显
 * @param {*} shopId 供应商Id
 * @returns
 */
export function getShopPopUp(params) {
  return request({
    url: '/user/customer/getShopPopUp',
    method: 'get',
    params
  })
}
/**
 * 供应商广告图列表
 * @param {*} shopName 供应商名称
 * @param {*} status 上架状态
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function getShopAdvertisingImage(params) {
  return request({
    url: '/user/customer/getShopAdvertisingImage',
    method: 'get',
    params
  })
}
/**
 * 供应商广告图信息保存
 * @param {*} id 广告Id
 * @param {*} shopId 供应商Id
 * @param {*} pcImage PC广告图
 * @param {*} appImage 小程序广告图
 * @param {*} jumpLink 跳转链接
 * @param {*} status 状态
 * @param {*} addTime 添加时间
 * @returns
 */
export function saveShopAdvertisingImage(data) {
  return request({
    url: '/user/customer/saveShopAdvertisingImage',
    method: 'post',
    data: data
  })
}
/**
 * 供应商广告图信息回显
 * @param {*} id 广告列表Id
 * @returns
 */
export function getShopAdvertisingImageById(id) {
  return request({
    url: '/user/customer/getShopAdvertisingImageById/' + id,
    method: 'get'
  })
}
/**
 * 供应商广告图排序
 * @param {*} id 广告列表Id
 * @param {*} sort 排序
 * @returns
 */
export function renewShopAdvertisingImageSort(params) {
  return request({
    url: '/user/customer/renewShopAdvertisingImageSort',
    method: 'get',
    params
  })
}
/**
 * 供应商广告图设置上下架状态
 * @param {*} id 广告列表Id
 * @param {*} status 状态
 * @returns
 */
export function renewShopAdvertisingImageStatus(params) {
  return request({
    url: '/user/customer/renewShopAdvertisingImageStatus',
    method: 'get',
    params
  })
}
/**
 * 删除广告
 * @param {*} id 广告Id
 * @returns
 */
export function delShopAdvertisingImage(id) {
  return request({
    url: '/user/customer/delShopAdvertisingImage/' + id,
    method: 'get'
  })
}
/**
 * 供应商主页统计
 * @param {*} shopId 供应商名称
 * @param {*} startTime 统计开始时间
 * @param {*} endTime 统计结束时间
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function getPageShop(params) {
  return request({
    url: '/user/customer/getPageShop',
    method: 'get',
    params
  })
}
/**
 * 供应商商品统计
 * @param {*} shopId 供应商名称
 * @param {*} startTime 统计开始时间
 * @param {*} endTime 统计结束时间
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function getPageShopProduct(params) {
  return request({
    url: '/user/customer/getPageShopProduct',
    method: 'get',
    params
  })
}
/**
 * 供应商文章统计
 * @param {*} shopId 供应商名称
 * @param {*} startTime 统计开始时间
 * @param {*} endTime 统计结束时间
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function getPageShopInfo(params) {
  return request({
    url: '/user/customer/getPageShopInfo',
    method: 'get',
    params
  })
}
/**
 * 供应商搜索词统计
 * @param {*} shopId 供应商名称
 * @param {*} startTime 统计开始时间
 * @param {*} endTime 统计结束时间
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function getPageShopKeyword(params) {
  return request({
    url: '/user/customer/getPageShopKeyword',
    method: 'get',
    params
  })
}
/**
 * 游客备注
 * @param {*} informationId 游客I都
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function getInformationNoteList(params) {
  return request({
    url: '/user/customer/getInformationNoteList',
    method: 'get',
    params
  })
}
/**
 * 保存游客备注
 * @param {*} id 备注Id
 * @param {*} informationId 游客Id
 * @param {*} note 备注
 * @param {*} appImage 小程序广告图
 * @param {*} jumpLink 跳转链接
 * @param {*} status 状态
 * @param {*} addTime 添加时间
 * @returns
 */
export function saveInformation(data) {
  return request({
    url: '/user/customer/saveInformation',
    method: 'post',
    data: data
  })
}
/**
 * 选择已上线供应商列表
 * @param {*} shopName
 * @param {*} pageNum,
 * @param {*} pageSize
 * @returns
 */
export function getMarketShopList(params) {
  return request({
    url: '/user/market/getShop',
    method: 'get',
    params
  })
}
/**
 * 营销供应商列表
 * @param {*} shopName
 * @param {*} pageNum,
 * @param {*} pageSize
 * @returns
 */
export function getMarkShopList(params) {
  return request({
    url: '/user/market/getMarkShopList',
    method: 'get',
    params
  })
}
/**
 * 保存数据报表供应商
 * @param {*} shopIds
 * @returns
 */
export function saveMarketShop(params) {
  return request({
    url: '/user/market/saveMarketShop',
    method: 'get',
    params
  })
}
/**
 * 保存logo
 * @param {*} id
 * @param {*} logo
 * @returns
 */
export function uploadShopLogo(params) {
  return request({
    url: '/user/market/uploadShopLogo',
    method: 'get',
    params
  })
}
/**
 * 数据报表列表
 * @param {*} marketId
 * @param {*} reportName
 * @param {*} pageNum,
 * @param {*} pageSize
 * @returns
 */
export function getMarketReportList(params) {
  return request({
    url: '/user/market/getMarketReport',
    method: 'get',
    params
  })
}
/**
 * 数据报表编辑回显
 * @param {*} id
 * @returns
 */
export function getMarketReportById(params) {
  return request({
    url: '/user/market/getMarketReportById',
    method: 'get',
    params
  })
}
/**
 * 生成报表
 * @param {*} id
 * @returns
 */
export function updateVisible(params) {
  return request({
    url: '/user/market/updateVisible',
    method: 'get',
    params
  })
}
/**
 * 删除报表
 * @param {*} id
 * @returns
 */
export function deleteMarketReport(params) {
  return request({
    url: '/user/market/deleteMarketReport',
    method: 'get',
    params
  })
}
/**
 * 上传数据文件
 * @param {*} reportDate 报表月份
 * @param {*} reportName 报表名称
 * @param {*} reportFile 文件
 * @returns
 */
export function saveMarketReport(data) {
  return request({
    url: '/user/market/saveMarketReport',
    method: 'post',
    data,
    headers: {
      'Content-Type': 'multipart/form-data'
    }
  })
}
/**
 * 保存报表
 * @param {*} reportDate 报表月份
 * @param {*} reportName 报表名称
 * @param {*} filePath 文件
 * @returns
 */
export function saveReport(params) {
  return request({
    url: '/user/market/saveReport',
    method: 'get',
    params
  })
}
/**
 * 供应商相关商品
 * @param {*} shopId
 * @param {*} productId
 * @param {*} productName
 * @param {*} pageNum,
 * @param {*} pageSize
 * @returns
 */
export function getProductList(params) {
  return request({
    url: '/user/customer/getProductList',
    method: 'get',
    params
  })
}
/**
 * 供应商商品列表
 * @param {*} id
 * @param {*} productId
 * @param {*} productName
 * @param {*} pageNum,
 * @param {*} pageSize
 * @returns
 */
export function getShopProduct(params) {
  return request({
    url: '/user/customer/getShopProduct',
    method: 'get',
    params
  })
}
/**
 * 保存潜客供应商统计商品
 * @param {*} id
 * @param {*} productIds
 * @returns
 */
export function saveShopProduct(params) {
  return request({
    url: '/user/customer/saveShopProduct',
    method: 'get',
    params
  })
}
/**
 * 设置供应商商品统计状态
 * @param {*} id 统计供应商商品表的ID
 * @param {*} status 状态
 * @returns
 */
export function renewShopProduct(params) {
  return request({
    url: '/user/customer/renewShopProduct',
    method: 'get',
    params
  })
}
/**
 * 删除供应商相关商品
 * @param {*} id
 * @returns
 */
export function deleteShopProduct(params) {
  return request({
    url: '/user/customer/deleteShopProduct',
    method: 'get',
    params
  })
}
/**
 * 获取供应商关联商品列表
 * @param {*} shopId
 * @returns
 */
export function getShopProductList(params) {
  return request({
    url: '/user/customer/getShopProductList',
    method: 'get',
    params
  })
}
