import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/* Router Modules */
import sysRouter from './modules/sys'
import userRouter from './modules/user'
import wechatRouter from './modules/wechat'
import webPageRouter from './modules/webPage'
import productRouter from './modules/product'
import financeRouter from './modules/finance'
import keywordLibraryRouter from './modules/keywordLibrary'
import memberRouter from './modules/member'
import mallProtraitRouter from './modules/mallPortrait'
import serviceSettlement from './modules/serviceSettlement'
// import tableRouter from './modules/table'
// import nestedRouter from './modules/nested'

/**
  // 当设置 true 的时候该路由不会在侧边栏出现 如401，login等页面，或者如一些编辑页面/edit/1
  hidden: true // (默认 false)
  //当设置 noRedirect 的时候该路由在面包屑导航中不可被点击
  redirect: 'noRedirect'
  // 当你一个路由下面的 children 声明的路由大于1个时，自动会变成嵌套的模式--如组件页面
  // 只有一个时，会将那个子路由当做根路由显示在侧边栏--如引导页面
  // 若你想不管路由下面的 children 声明的个数都显示你的根路由
  // 你可以设置 alwaysShow: true，这样它就会忽略之前定义的规则，一直显示根路由
  alwaysShow: true

  name: 'router-name' // 设定路由的名字，一定要填写不然使用<keep-alive>时会出现各种问题
  meta: {
    roles: ['admin', 'editor'] // 设置该路由进入的权限，支持多个权限叠加
    title: 'title' // 设置该路由在侧边栏和面包屑中展示的名字
    icon: 'svg-name' // 设置该路由的图标，支持 svg-class，也支持 el-icon-x element-ui 的 icon
    noCache: true // 如果设置为true，则不会被 <keep-alive> 缓存(默认 false)
    breadcrumb: false //  如果设置为false，则不会在breadcrumb面包屑中显示(默认 true)
    affix: true // 如果设置为true，它则会固定在tags-view中(默认 false)

    // 当路由设置了该属性，则会高亮相对应的侧边栏。
    // 这在某些场景非常有用，比如：一个文章的列表页路由为：/article/list
    // 点击文章进入文章详情页，这时候路由为/article/1，但你想在侧边栏高亮文章列表的路由，就可以进行如下设置
    activeMenu: '/article/list'
  }
 */

// 基础路由
export const constantRoutes = [
  {
    path: '/',
    component: Layout,
    redirect: '/dashboard',
    children: [
      {
        path: 'dashboard',
        component: () => import('@/views/dashboard/index'),
        name: 'Dashboard',
        meta: { title: '采美后台', icon: 'dashboard', affix: true }
      }
    ]
  },
  {
    path: '/redirect',
    component: Layout,
    hidden: true,
    children: [
      {
        path: '/redirect/:path(.*)',
        component: () => import('@/views/sys/redirect/index')
      }
    ]
  },
  {
    path: '/login',
    component: () => import('@/views/sys/login/index'),
    hidden: true
  },
  {
    path: '/profile',
    component: Layout,
    redirect: '/profile/index',
    hidden: true,
    children: [
      {
        path: 'index',
        component: () => import('@/views/sys/profile/index'),
        name: 'Profile',
        meta: { title: '个人中心', icon: 'user', noCache: true }
      }
    ]
  }
]

// 默认路由列表
export const asyncRoutes = [
  sysRouter,
  userRouter,
  webPageRouter,
  productRouter,
  financeRouter,
  wechatRouter,
  memberRouter,
  keywordLibraryRouter,
  mallProtraitRouter,
  serviceSettlement
]

/**
 * afterRoutes
 * a base page that does not have permission requirements And last loaded
 * all roles can be accessed
 */
export const afterRoutes = [
  {
    path: 'external-link',
    component: Layout,
    children: [
      {
        path: 'https://www.caimei365.com/',
        meta: { title: '采美365', icon: 'link' }
      }
    ]
  },
  {
    path: '/404',
    component: () => import('@/views/sys/error/404'),
    hidden: true
  },
  {
    path: '/401',
    component: () => import('@/views/sys/error/401'),
    hidden: true
  },
  // 404 page must be placed at the end !!!
  { path: '*', redirect: '/404', hidden: true }
]
// 创建路由对象
const createRouter = () =>
  new Router({
    // mode: 'history', // require service support
    scrollBehavior: () => ({ y: 0 }),
    routes: constantRoutes
  })

const router = createRouter()

// 重置路由
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
