/** When your routing table is too long, you can split it into small modules **/

import Layout from '@/layout'

const keywordLibraryRouter = {
  path: '/library',
  component: Layout,
  redirect: '/library/keyword',
  alwaysShow: true, // will always show the root menu
  name: 'UserKeywordCount', // name必须和后台配置一致，不然匹配不到
  meta: { title: '关键词库' },
  children: [
    {
      path: 'keyword',
      name: 'KeywordMenu',
      redirect: '/library/keyword/list',
      component: () => import('@/views/index'),
      meta: { title: '关键词统计' },
      children: [
        {
          path: 'list',
          name: 'KeywordList',
          component: () => import('@/views/library/keyword/list'),
          meta: { title: '关键词列表' }
        },
        {
          path: 'recommend',
          name: 'KeywordRecommend',
          component: () => import('@/views/library/keyword/recommend'),
          meta: { title: '关键词推荐' }
        }
      ]
    },
    {
      path: 'tag',
      name: 'TagMenu',
      redirect: '/library/tag/list',
      alwaysShow: true,
      component: () => import('@/views/index'),
      meta: { title: '标签库', useDefault: true },
      children: [
        {
          path: 'list',
          name: 'TagList',
          component: () => import('@/views/library/tag/list'),
          meta: { title: '动态标签列表' }
        },
        {
          path: 'static-list',
          name: 'StaticList',
          component: () => import('@/views/library/tag/static-list'),
          meta: { title: '静态标签列表' }
        },
        {
          path: 'tag-form',
          name: 'TagForm',
          component: () => import('@/views/library/tag/tag-form'),
          meta: { title: '动态标签添加/编辑' }
        },
        {
          path: 'priority-list',
          name: 'PriorityList',
          component: () => import('@/views/library/tag/priority-list'),
          meta: { title: '优先展示标签' }
        }
      ]
    },
    {
      path: 'supplierTag',
      name: 'SupplierTagMenu',
      redirect: '/library/supplierTag/list',
      alwaysShow: true,
      component: () => import('@/views/index'),
      meta: { title: '供应商关联标签' },
      children: [
        {
          path: 'list',
          name: 'SupplierList',
          component: () => import('@/views/library/supplierTag/supplier-list'),
          meta: { title: '供应商列表' }
        },
        {
          path: 'tagList',
          hidden: true,
          component: () => import('@/views/library/supplierTag/list'),
          name: 'SupplierTagList',
          meta: { title: '标签列表', noCache: true, activeMenu: '/library/supplierTag/' }
        }
      ]
    }
  ]
}
export default keywordLibraryRouter
